# Running Matlab Script on the Cluster

## Matlab Script (initial version)
Let's save the following code as a file `findPrimes_Script.m`. Here we have defined a function to compute primes between two numbers. Instead of typing three lines in Matlab, we'll just invoke this function with a single command.
```
function findPrimes_Script(x,y)
  fprintf('Printing primes between: %d and %d\n', x, y);
  n = x:y;
  p = isprime(n);
  n(p)
  exit
end
```
### Invoke Matlab Script (initial version)

To find the primes between two integers, type the following commands, one at a time.

```
matlab -nodisplay -r "findPrimes_Script(1,50)"
matlab -nodisplay -r "findPrimes_Script(50,100)"
matlab -nodisplay -r "findPrimes_Script(100,200)"
```

## Matlab Script (intermediate version)

So far, we have said that clusters can run things faster, but we haven't done any measurements. Let's add some code to measure how much time Matlab takes to compute all primes between x and y. We'll use the built-in `tic; toc;` functions (**Are these functions?? macros??**) in Matlab. Edit the previous code as follows, or just copy the code to a new file named `findPrimes_Script_Timing.m`.

```
function findPrimes_Script_Timing(x,y)
  fprintf('Printing primes between: %d and %d\n', x, y);
  n = x:y;
  tic;
  p = isprime(n);
  elapsed = toc;
  n(p)
  fprintf('Total time taken to compute: %f\n', elapsed);
  exit
end
```

### Invoke Matlab Script (intermediate version)

- Let's now measure how long Matlab takes to compute times between (1,100), (1,10000), (1,100000) etc. Type each of the following commands, one at a time.
```
matlab -nodisplay -singleCompThread -r "findPrimes_Script_Timing(1,100)"
matlab -nodisplay -singleCompThread -r "findPrimes_Script_Timing(1,10000)"
matlab -nodisplay -singleCompThread -r "findPrimes_Script_Timing(1,100000)"
```
- Notice that, so far, it doesn't take long. Only after hitting 100000, there is a visible delay.


## Matlab Script (final version)

- The output on screen has grown unmanageable. Before proceeding further, let's save the output to a file. 
- Edit the previous code as follows, or copy the code below and save it in a file named `findPrimes_Final.m`
- This will generate an output file called `prime_numbers_x_y.txt`, where x and y are the ranges of the search.

```
function result = findPrimes_Final(x,y)
  fprintf('Printing primes between: %d and %d\n', x, y);
  n = x:y;
  tic;
  p = isprime(n);
  elapsed = toc;
  outfile = sprintf('prime_numbers_%d_%d.txt', x, y);
  fid = fopen(outfile, 'w');
  fprintf(fid, '%ld\n', n(p));
  fclose(fid);
  fprintf('Total time taken to compute: %f\n', elapsed);
  exit
end
```

### Invoke Matlab Script (final version)
```
matlab -nodisplay -singleCompThread -r "findPrimes_Final(1,100)"
matlab -nodisplay -singleCompThread -r "findPrimes_Final(1,10000)"
matlab -nodisplay -singleCompThread -r "findPrimes_Final(1,100000)"
```
- Open each output file and see the numbers.
- Check how many primes are there in each range.
- Before running the script with even larger numbers, we need to understand some basics. Back to slides!

