# Finding primes in a batch job

Before progressing further, let's start from a clean directory.
```
mkdir jobs
cd jobs
```

Now we are in the empty directory jobs. Let's copy over out Matlab scripts here.
```
cp ~/cluster101/scripts/findPrimes_Final.m .
```


## Job Submission Script (initial version)
- At a minimum, the jobscript must include the command that you used in the terminal to run the Matlab script. Let's save the following command as a file `compute_primes.sub`.
```
matlab -nodisplay -singleCompThread -r "findPrimes_Final(1,100)"
```
- Now submit the job:   
```
qsub compute_primes.sub
```
- Let's see which new files were generated.
- Wow, there are lots of errors there. The sytem didn't find Matlab!

## Job Submission Script (fix missing Matlab)
- Let's edit our job submission script as follows and resubmit it. Save the following as `compute_primes.sub`.
```
module load matlab

matlab -nodisplay -singleCompThread -r "findPrimes_Final(1,100)"
```
- Then run:
```
qsub compute_primes.sub
```
- Matlab still didn't run! This time it couldn't find the script `findPrimes_Final.m`

## Job Submission Script (correct version)
- When a job starts, it always starts from your home directory. So, if the script is in a non-standard location, you need to navigate to that directory.
- In this case, the script was in the same directory from where we ran the `qsub` command. We'll add the following lines in our jobscript. Again, save it as `compute_primes.sub`.
```
echo "Current working directory: $PWD"
cd $PBS_O_WORKDIR
echo "Working directory changed to: $PWD"

module load matlab

matlab -nodisplay -singleCompThread -r "findPrimes_Final(1,100)"
```
- Let's look at the output and error files.
- Yayy! Matlab generated our output file `prime_numbers_1_100.txt`
