- How to parallelize your work I (30 mins)
- Run lots of tasks each single-core
- Node access policy (why sharing a node is bad)
- Introduce parafly
- Modify jobscript to use parafly
- Do not run too many matlabs, you?ll exhaust the licenses!
- Run job

## How can I finish my work faster?

We explained earlier that although clusters are very powerful you need to use them *efficiently* to take advantage of their capabilities. For most scientific problems, you can finish your computation faster by running things in parallel. So, instead of one copy of your program, you run several copies of them **all at the same time**. This is very useful for computations that can easily be split into disjoint parts, for example, you need to run your simulations with varying initial conditions.

Even for problems that cannot easily be split into sub-problems, there are other approaches to parallelize their internal functions. For example, a lot of linear algebra operations can be run in parallel and there are libraries that do that. You just need to use these libraries in your code.

In the case of the prime example, we want to compute all primes between 1 and 10,000,000. This can be easily split into multiple problems, e.g., find primes between 1-1M, 1M-2M, 2M-3M, and so on. We will use this intuition to parallelize our work.

In other words, we want to keep all 4-cores in the job occupied by running 4 Matlab processes. There are various ways to accomplish this. We will use a tool name ParaFly that can run programs in parallel and keep track of their progress.

## ParaFly

ParaFly allows you to run multiple commands in parallel inside a job. It needs a list of commands as input and how many parallel processes (*CPUS*) you want to run. It then iteratively runs those commands by keeping `N` *CPUS* busy at a time.

- To use parafly, you need to fist load the `utilities` module and then load the `parafly` module. You must add the following lines in your jobscript.
```
module load utilities
module load parafly
```

- Next step is to create a list of commands as follows. Save the commands in a file named `matlab_commands.txt`.
``` 
matlab -nodisplay -singleCompThread -r "findPrimes_Final(8000001,10000000)"
matlab -nodisplay -singleCompThread -r "findPrimes_Final(6000001,8000000)"
matlab -nodisplay -singleCompThread -r "findPrimes_Final(4000001,6000000)"
matlab -nodisplay -singleCompThread -r "findPrimes_Final(2000001,4000000)"
matlab -nodisplay -singleCompThread -r "findPrimes_Final(1,2000000)"
```

- Next, we edit our previous jobscript to run Matlab with Parafly. Save the following as a file named `findPrimes_Parafly.sub`.
```
#PBS -l nodes=1:ppn=4
#PBS -l walltime=10:00
#PBS -l naccesspolicy=shared
#PBS -q scholar
#PBS -N find_primes_1_10000000
#

cd $PBS_O_WORKDIR
echo "Working directory changed to: $PWD"

module load matlab
module load utilities
module load parafly

echo "Starting parafly at `date`"
ParaFly  -c matlab_commands.txt -CPU 4 -failed_cmds rerun.txt
echo "Finished parafly at `date`"
```

- Now, submit the jobscript and wait for it to finish.
```
qsub findPrimes_Parafly.sub
```
