# Cluster101Scripts
## GUI Commands
```
n = 1:100;
p = isprime(n);
n(p)

n = 1:10000;
p = isprime(n);
n(p)

n = 1:100000;
p = isprime(n);
n(p)
```

## Matlab Script (v1)
```
function findPrimes_Script(x,y)
  fprintf('Printing primes between: %d and %d\n', x, y);
  n = x:y;
  p = isprime(n);
  n(p)
  exit
end
```
### Invoke Matlab Script (v1)
```
matlab -nodisplay -r "findPrimes_Script(1,50)"
matlab -nodisplay -r "findPrimes_Script(50,100)"
matlab -nodisplay -r "findPrimes_Script(100,200)"
```
## Matlab Script (v2)
Add some time measurement capability.
```
function findPrimes_Script_Timing(x,y)
  fprintf('Printing primes between: %d and %d\n', x, y);
  n = x:y;
  tic;
  p = isprime(n);
  elapsed = toc;
  n(p)
  fprintf('Total time taken to compute: %f\n', elapsed);
  exit
end
```
### Invoke Matlab Script (v2)
```
matlab -nodisplay -singleCompThread -r "findPrimes_Script_Timing(1,100)"
matlab -nodisplay -singleCompThread -r "findPrimes_Script_Timing(1,10000)"
matlab -nodisplay -singleCompThread -r "findPrimes_Script_Timing(1,100000)"
```

## Matlab Script (v3)
Save output to a file.
```
function result = findPrimes_Final(x,y)
  fprintf('Printing primes between: %d and %d\n', x, y);
  n = x:y;
  tic;
  p = isprime(n);
  elapsed = toc;
  outfile = sprintf('prime_numbers_%d_%d.txt', x, y);
  fid = fopen(outfile, 'w');
  fprintf(fid, '%ld\n', n(p));
  fclose(fid);
  fprintf('Total time taken to compute: %f\n', elapsed);
  exit
end
```
### Invoke Matlab Script (v3)
```
matlab -nodisplay -singleCompThread -r "findPrimes_Final(1,100)"
matlab -nodisplay -singleCompThread -r "findPrimes_Final(1,10000)"
matlab -nodisplay -singleCompThread -r "findPrimes_Final(1,100000)"
```

## Job Submission Script (v1)
```
matlab -nodisplay -singleCompThread -r "findPrimes_Final(1,100)"
```

## Job Submission Script (v2)
```
module load matlab

matlab -nodisplay -singleCompThread -r "findPrimes_Final(1,100)"
```
## Job Submission Script (v3)
```
echo "Current working directory: $PWD"
cd $PBS_O_WORKDIR
echo "Working directory changed to: $PWD"

module load matlab

matlab -nodisplay -singleCompThread -r "findPrimes_Final(1,100)"
```
## Job Submission Script (v4)
Compute primes from 1-10,000,000 in serial.
```
echo "Current working directory: $PWD"
cd $PBS_O_WORKDIR
echo "Working directory changed to: $PWD"

module load matlab

matlab -nodisplay -singleCompThread -r "findPrimes_Final(1,10000000)"
```
## Run Multiple Tasks in Parallel (ParaFly)
### Matlab Commands
Put all Matlab commands in a file named `matlab_commands.txt`
```
matlab -nodisplay -singleCompThread -r "findPrimes_Final(8000001,10000000)"
matlab -nodisplay -singleCompThread -r "findPrimes_Final(6000001,8000000)"
matlab -nodisplay -singleCompThread -r "findPrimes_Final(4000001,6000000)"
matlab -nodisplay -singleCompThread -r "findPrimes_Final(2000001,4000000)"
matlab -nodisplay -singleCompThread -r "findPrimes_Final(1,2000000)"
```
### Job Submission Script with ParaFly
```
#PBS -l nodes=1:ppn=4
#PBS -l walltime=10:00
#PBS -l naccesspolicy=shared
#PBS -q scholar
#PBS -N find_primes_1_10000000
#

cd $PBS_O_WORKDIR
echo "Working directory changed to: $PWD"

module load matlab
module load utilities
module load parafly

echo "Starting parafly at `date`"
ParaFly  -c matlab_commands.txt -CPU 4 -failed_cmds rerun.txt
echo "Finished parafly at `date`"
```
